# How to cite

Please cite our paper on the Journal of Open Source Software [![DOI](https://joss.theoj.org/papers/10.21105/joss.05967/status.svg)](https://doi.org/10.21105/joss.05967)

Jiang et al., (2023). Seaduck: A python package for Eulerian and Lagrangian interpolation on ocean datasets. Journal of Open Source Software, 8(92), 5967, https://doi.org/10.21105/joss.05967
